---
title: Helm Chart Values
menuTitle: Helm chart values
description: Reference for Helm Chart values.
aliases:
  - ../../../installation/helm/reference/
weight: 500
keywords: []
---

<!-- Autogenerated. Modify ../production/helm/loki/reference.md.gotmpl -->

# Helm Chart Values
<!-- vale Grafana.Quotes = NO -->
<!-- The reference title is required. Use a noun-based title. -->
<!-- vale Grafana.Quotes = YES -->

This is the generated reference for the Loki Helm Chart values.

> **Note:** This reference is for the Loki Helm chart version 3.0 or greater.
> If you are using the `grafana/loki-stack` Helm chart from the community repo,
> please refer to the `values.yaml` of the respective Github repository
> [grafana/helm-charts](https://github.com/grafana/helm-charts/tree/main/charts/loki-stack).

<!-- Override default values table from helm-docs. See https://github.com/norwoodj/helm-docs/tree/master#advanced-table-rendering -->

{{< responsive-table >}}
<table>
	<thead>
		<th>Key</th>
		<th>Type</th>
		<th>Description</th>
		<th>Default</th>
	</thead>
	<tbody>
		<tr>
			<td>backend.affinity</td>
			<td>string</td>
			<td>Affinity for backend pods. Passed through `tpl` and, thus, to be configured as string</td>
			<td><pre lang="">
Hard node and soft zone anti-affinity
</pre>
</td>
		</tr>
		<tr>
			<td>backend.annotations</td>
			<td>object</td>
			<td>Annotations for backend StatefulSet</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>backend.autoscaling.behavior</td>
			<td>object</td>
			<td>Behavior policies while scaling.</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>backend.autoscaling.enabled</td>
			<td>bool</td>
			<td>Enable autoscaling for the backend.</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>backend.autoscaling.maxReplicas</td>
			<td>int</td>
			<td>Maximum autoscaling replicas for the backend.</td>
			<td><pre lang="json">
3
</pre>
</td>
		</tr>
		<tr>
			<td>backend.autoscaling.minReplicas</td>
			<td>int</td>
			<td>Minimum autoscaling replicas for the backend.</td>
			<td><pre lang="json">
1
</pre>
</td>
		</tr>
		<tr>
			<td>backend.autoscaling.targetCPUUtilizationPercentage</td>
			<td>int</td>
			<td>Target CPU utilization percentage for the backend.</td>
			<td><pre lang="json">
60
</pre>
</td>
		</tr>
		<tr>
			<td>backend.autoscaling.targetMemoryUtilizationPercentage</td>
			<td>string</td>
			<td>Target memory utilization percentage for the backend.</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>backend.extraArgs</td>
			<td>list</td>
			<td>Additional CLI args for the backend</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>backend.extraEnv</td>
			<td>list</td>
			<td>Environment variables to add to the backend pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>backend.extraEnvFrom</td>
			<td>list</td>
			<td>Environment variables from secrets or configmaps to add to the backend pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>backend.extraVolumeMounts</td>
			<td>list</td>
			<td>Volume mounts to add to the backend pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>backend.extraVolumes</td>
			<td>list</td>
			<td>Volumes to add to the backend pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>backend.image.registry</td>
			<td>string</td>
			<td>The Docker registry for the backend image. Overrides `loki.image.registry`</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>backend.image.repository</td>
			<td>string</td>
			<td>Docker image repository for the backend image. Overrides `loki.image.repository`</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>backend.image.tag</td>
			<td>string</td>
			<td>Docker image tag for the backend image. Overrides `loki.image.tag`</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>backend.initContainers</td>
			<td>list</td>
			<td>Init containers to add to the backend pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>backend.nodeSelector</td>
			<td>object</td>
			<td>Node selector for backend pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>backend.persistence.enableStatefulSetAutoDeletePVC</td>
			<td>bool</td>
			<td>Enable StatefulSetAutoDeletePVC feature</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>backend.persistence.selector</td>
			<td>string</td>
			<td>Selector for persistent disk</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>backend.persistence.size</td>
			<td>string</td>
			<td>Size of persistent disk</td>
			<td><pre lang="json">
"10Gi"
</pre>
</td>
		</tr>
		<tr>
			<td>backend.persistence.storageClass</td>
			<td>string</td>
			<td>Storage class to be used. If defined, storageClassName: <storageClass>. If set to "-", storageClassName: "", which disables dynamic provisioning. If empty or set to null, no storageClassName spec is set, choosing the default provisioner (gp2 on AWS, standard on GKE, AWS, and OpenStack).</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>backend.podAnnotations</td>
			<td>object</td>
			<td>Annotations for backend pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>backend.podLabels</td>
			<td>object</td>
			<td>Additional labels for each `backend` pod</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>backend.podManagementPolicy</td>
			<td>string</td>
			<td>The default is to deploy all pods in parallel.</td>
			<td><pre lang="json">
"Parallel"
</pre>
</td>
		</tr>
		<tr>
			<td>backend.priorityClassName</td>
			<td>string</td>
			<td>The name of the PriorityClass for backend pods</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>backend.replicas</td>
			<td>int</td>
			<td>Number of replicas for the backend</td>
			<td><pre lang="json">
3
</pre>
</td>
		</tr>
		<tr>
			<td>backend.resources</td>
			<td>object</td>
			<td>Resource requests and limits for the backend</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>backend.selectorLabels</td>
			<td>object</td>
			<td>Additional selector labels for each `backend` pod</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>backend.serviceLabels</td>
			<td>object</td>
			<td>Labels for ingester service</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>backend.targetModule</td>
			<td>string</td>
			<td>Comma-separated list of Loki modules to load for the read</td>
			<td><pre lang="json">
"backend"
</pre>
</td>
		</tr>
		<tr>
			<td>backend.terminationGracePeriodSeconds</td>
			<td>int</td>
			<td>Grace period to allow the backend to shutdown before it is killed. Especially for the ingester, this must be increased. It must be long enough so backends can be gracefully shutdown flushing/transferring all data and to successfully leave the member ring on shutdown.</td>
			<td><pre lang="json">
300
</pre>
</td>
		</tr>
		<tr>
			<td>backend.tolerations</td>
			<td>list</td>
			<td>Tolerations for backend pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>clusterLabelOverride</td>
			<td>string</td>
			<td>Overrides the chart's cluster label</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.adminApi</td>
			<td>object</td>
			<td>If enabled, the correct admin_client storage will be configured. If disabled while running enterprise, make sure auth is set to `type: trust`, or that `auth_enabled` is set to `false`.</td>
			<td><pre lang="json">
{
  "enabled": true
}
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.adminToken.additionalNamespaces</td>
			<td>list</td>
			<td>Additional namespace to also create the token in. Useful if your Grafana instance is in a different namespace</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.adminToken.secret</td>
			<td>string</td>
			<td>Alternative name for admin token secret, needed by tokengen and provisioner jobs</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.canarySecret</td>
			<td>string</td>
			<td>Alternative name of the secret to store token for the canary</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.cluster_name</td>
			<td>string</td>
			<td>Optional name of the GEL cluster, otherwise will use .Release.Name The cluster name must match what is in your GEL license</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.config</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"{{- if .Values.enterprise.adminApi.enabled }}\n{{- if or .Values.minio.enabled (eq .Values.loki.storage.type \"s3\") (eq .Values.loki.storage.type \"gcs\") (eq .Values.loki.storage.type \"azure\") }}\nadmin_client:\n  storage:\n    s3:\n      bucket_name: {{ .Values.loki.storage.bucketNames.admin }}\n{{- end }}\n{{- end }}\nauth:\n  type: {{ .Values.enterprise.adminApi.enabled | ternary \"enterprise\" \"trust\" }}\nauth_enabled: {{ .Values.loki.auth_enabled }}\ncluster_name: {{ include \"loki.clusterName\" . }}\nlicense:\n  path: /etc/loki/license/license.jwt\n"
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.enabled</td>
			<td>bool</td>
			<td></td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.externalConfigName</td>
			<td>string</td>
			<td>Name of the external config secret to use</td>
			<td><pre lang="json">
""
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.externalLicenseName</td>
			<td>string</td>
			<td>Name of external license secret to use</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.image.digest</td>
			<td>string</td>
			<td>Overrides the image tag with an image digest</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.image.pullPolicy</td>
			<td>string</td>
			<td>Docker image pull policy</td>
			<td><pre lang="json">
"IfNotPresent"
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.image.registry</td>
			<td>string</td>
			<td>The Docker registry</td>
			<td><pre lang="json">
"docker.io"
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.image.repository</td>
			<td>string</td>
			<td>Docker image repository</td>
			<td><pre lang="json">
"grafana/enterprise-logs"
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.image.tag</td>
			<td>string</td>
			<td>Docker image tag</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.license</td>
			<td>object</td>
			<td>Grafana Enterprise Logs license In order to use Grafana Enterprise Logs features, you will need to provide the contents of your Grafana Enterprise Logs license, either by providing the contents of the license.jwt, or the name Kubernetes Secret that contains your license.jwt. To set the license contents, use the flag `--set-file 'enterprise.license.contents=./license.jwt'`</td>
			<td><pre lang="json">
{
  "contents": "NOTAVALIDLICENSE"
}
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner</td>
			<td>object</td>
			<td>Configuration for `provisioner` target</td>
			<td><pre lang="json">
{
  "additionalTenants": [],
  "annotations": {},
  "enabled": true,
  "env": [],
  "extraVolumeMounts": [],
  "image": {
    "digest": null,
    "pullPolicy": "IfNotPresent",
    "registry": "docker.io",
    "repository": "grafana/enterprise-logs-provisioner",
    "tag": null
  },
  "labels": {},
  "priorityClassName": null,
  "provisionedSecretPrefix": null,
  "securityContext": {
    "fsGroup": 10001,
    "runAsGroup": 10001,
    "runAsNonRoot": true,
    "runAsUser": 10001
  }
}
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.additionalTenants</td>
			<td>list</td>
			<td>Additional tenants to be created. Each tenant will get a read and write policy and associated token. Tenant must have a name and a namespace for the secret containting the token to be created in. For example additionalTenants:   - name: loki     secretNamespace: grafana</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.annotations</td>
			<td>object</td>
			<td>Additional annotations for the `provisioner` Job</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.enabled</td>
			<td>bool</td>
			<td>Whether the job should be part of the deployment</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.env</td>
			<td>list</td>
			<td>Additional Kubernetes environment</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.extraVolumeMounts</td>
			<td>list</td>
			<td>Volume mounts to add to the provisioner pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.image</td>
			<td>object</td>
			<td>Provisioner image to Utilize</td>
			<td><pre lang="json">
{
  "digest": null,
  "pullPolicy": "IfNotPresent",
  "registry": "docker.io",
  "repository": "grafana/enterprise-logs-provisioner",
  "tag": null
}
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.image.digest</td>
			<td>string</td>
			<td>Overrides the image tag with an image digest</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.image.pullPolicy</td>
			<td>string</td>
			<td>Docker image pull policy</td>
			<td><pre lang="json">
"IfNotPresent"
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.image.registry</td>
			<td>string</td>
			<td>The Docker registry</td>
			<td><pre lang="json">
"docker.io"
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.image.repository</td>
			<td>string</td>
			<td>Docker image repository</td>
			<td><pre lang="json">
"grafana/enterprise-logs-provisioner"
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.image.tag</td>
			<td>string</td>
			<td>Overrides the image tag whose default is the chart's appVersion</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.labels</td>
			<td>object</td>
			<td>Additional labels for the `provisioner` Job</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.priorityClassName</td>
			<td>string</td>
			<td>The name of the PriorityClass for provisioner Job</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.provisionedSecretPrefix</td>
			<td>string</td>
			<td>Name of the secret to store provisioned tokens in</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.securityContext</td>
			<td>object</td>
			<td>Run containers as user `enterprise-logs(uid=10001)`</td>
			<td><pre lang="json">
{
  "fsGroup": 10001,
  "runAsGroup": 10001,
  "runAsNonRoot": true,
  "runAsUser": 10001
}
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.tokengen</td>
			<td>object</td>
			<td>Configuration for `tokengen` target</td>
			<td><pre lang="json">
{
  "annotations": {},
  "enabled": true,
  "env": [],
  "extraArgs": [],
  "extraEnvFrom": [],
  "extraVolumeMounts": [],
  "extraVolumes": [],
  "labels": {},
  "priorityClassName": "",
  "securityContext": {
    "fsGroup": 10001,
    "runAsGroup": 10001,
    "runAsNonRoot": true,
    "runAsUser": 10001
  },
  "targetModule": "tokengen",
  "tolerations": []
}
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.tokengen.annotations</td>
			<td>object</td>
			<td>Additional annotations for the `tokengen` Job</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.tokengen.enabled</td>
			<td>bool</td>
			<td>Whether the job should be part of the deployment</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.tokengen.env</td>
			<td>list</td>
			<td>Additional Kubernetes environment</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.tokengen.extraArgs</td>
			<td>list</td>
			<td>Additional CLI arguments for the `tokengen` target</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.tokengen.extraEnvFrom</td>
			<td>list</td>
			<td>Environment variables from secrets or configmaps to add to the tokengen pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.tokengen.extraVolumeMounts</td>
			<td>list</td>
			<td>Additional volume mounts for Pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.tokengen.extraVolumes</td>
			<td>list</td>
			<td>Additional volumes for Pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.tokengen.labels</td>
			<td>object</td>
			<td>Additional labels for the `tokengen` Job</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.tokengen.priorityClassName</td>
			<td>string</td>
			<td>The name of the PriorityClass for tokengen Pods</td>
			<td><pre lang="json">
""
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.tokengen.securityContext</td>
			<td>object</td>
			<td>Run containers as user `enterprise-logs(uid=10001)`</td>
			<td><pre lang="json">
{
  "fsGroup": 10001,
  "runAsGroup": 10001,
  "runAsNonRoot": true,
  "runAsUser": 10001
}
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.tokengen.targetModule</td>
			<td>string</td>
			<td>Comma-separated list of Loki modules to load for tokengen</td>
			<td><pre lang="json">
"tokengen"
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.tokengen.tolerations</td>
			<td>list</td>
			<td>Tolerations for tokengen Job</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.useExternalLicense</td>
			<td>bool</td>
			<td>Set to true when providing an external license</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.version</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"v1.7.3"
</pre>
</td>
		</tr>
		<tr>
			<td>extraObjects</td>
			<td>list</td>
			<td></td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>fullnameOverride</td>
			<td>string</td>
			<td>Overrides the chart's computed fullname</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.affinity</td>
			<td>string</td>
			<td>Affinity for gateway pods. Passed through `tpl` and, thus, to be configured as string</td>
			<td><pre lang="">
Hard node and soft zone anti-affinity
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.annotations</td>
			<td>object</td>
			<td>Annotations for gateway deployment</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.autoscaling.behavior</td>
			<td>object</td>
			<td>Behavior policies while scaling.</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.autoscaling.enabled</td>
			<td>bool</td>
			<td>Enable autoscaling for the gateway</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.autoscaling.maxReplicas</td>
			<td>int</td>
			<td>Maximum autoscaling replicas for the gateway</td>
			<td><pre lang="json">
3
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.autoscaling.minReplicas</td>
			<td>int</td>
			<td>Minimum autoscaling replicas for the gateway</td>
			<td><pre lang="json">
1
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.autoscaling.targetCPUUtilizationPercentage</td>
			<td>int</td>
			<td>Target CPU utilisation percentage for the gateway</td>
			<td><pre lang="json">
60
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.autoscaling.targetMemoryUtilizationPercentage</td>
			<td>string</td>
			<td>Target memory utilisation percentage for the gateway</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.basicAuth.enabled</td>
			<td>bool</td>
			<td>Enables basic authentication for the gateway</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.basicAuth.existingSecret</td>
			<td>string</td>
			<td>Existing basic auth secret to use. Must contain '.htpasswd'</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.basicAuth.htpasswd</td>
			<td>string</td>
			<td>Uses the specified users from the `loki.tenants` list to create the htpasswd file if `loki.tenants` is not set, the `gateway.basicAuth.username` and `gateway.basicAuth.password` are used The value is templated using `tpl`. Override this to use a custom htpasswd, e.g. in case the default causes high CPU load.</td>
			<td><pre lang="json">
"{{ if .Values.loki.tenants }}\n  {{- range $t := .Values.loki.tenants }}\n{{ htpasswd (required \"All tenants must have a 'name' set\" $t.name) (required \"All tenants must have a 'password' set\" $t.password) }}\n  {{- end }}\n{{ else }} {{ htpasswd (required \"'gateway.basicAuth.username' is required\" .Values.gateway.basicAuth.username) (required \"'gateway.basicAuth.password' is required\" .Values.gateway.basicAuth.password) }} {{ end }}"
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.basicAuth.password</td>
			<td>string</td>
			<td>The basic auth password for the gateway</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.basicAuth.username</td>
			<td>string</td>
			<td>The basic auth username for the gateway</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.containerSecurityContext</td>
			<td>object</td>
			<td>The SecurityContext for gateway containers</td>
			<td><pre lang="json">
{
  "allowPrivilegeEscalation": false,
  "capabilities": {
    "drop": [
      "ALL"
    ]
  },
  "readOnlyRootFilesystem": true
}
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.deploymentStrategy.type</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"RollingUpdate"
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.enabled</td>
			<td>bool</td>
			<td>Specifies whether the gateway should be enabled</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.extraArgs</td>
			<td>list</td>
			<td>Additional CLI args for the gateway</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.extraEnv</td>
			<td>list</td>
			<td>Environment variables to add to the gateway pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.extraEnvFrom</td>
			<td>list</td>
			<td>Environment variables from secrets or configmaps to add to the gateway pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.extraVolumeMounts</td>
			<td>list</td>
			<td>Volume mounts to add to the gateway pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.extraVolumes</td>
			<td>list</td>
			<td>Volumes to add to the gateway pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.image.digest</td>
			<td>string</td>
			<td>Overrides the gateway image tag with an image digest</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.image.pullPolicy</td>
			<td>string</td>
			<td>The gateway image pull policy</td>
			<td><pre lang="json">
"IfNotPresent"
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.image.registry</td>
			<td>string</td>
			<td>The Docker registry for the gateway image</td>
			<td><pre lang="json">
"docker.io"
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.image.repository</td>
			<td>string</td>
			<td>The gateway image repository</td>
			<td><pre lang="json">
"nginxinc/nginx-unprivileged"
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.image.tag</td>
			<td>string</td>
			<td>The gateway image tag</td>
			<td><pre lang="json">
"1.23-alpine"
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.ingress.annotations</td>
			<td>object</td>
			<td>Annotations for the gateway ingress</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.ingress.enabled</td>
			<td>bool</td>
			<td>Specifies whether an ingress for the gateway should be created</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.ingress.hosts</td>
			<td>list</td>
			<td>Hosts configuration for the gateway ingress</td>
			<td><pre lang="json">
[
  {
    "host": "gateway.loki.example.com",
    "paths": [
      {
        "path": "/"
      }
    ]
  }
]
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.ingress.ingressClassName</td>
			<td>string</td>
			<td>Ingress Class Name. MAY be required for Kubernetes versions >= 1.18</td>
			<td><pre lang="json">
""
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.ingress.labels</td>
			<td>object</td>
			<td>Labels for the gateway ingress</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.ingress.tls</td>
			<td>list</td>
			<td>TLS configuration for the gateway ingress</td>
			<td><pre lang="json">
[
  {
    "hosts": [
      "gateway.loki.example.com"
    ],
    "secretName": "loki-gateway-tls"
  }
]
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.lifecycle</td>
			<td>object</td>
			<td>Lifecycle for the gateway container</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.nginxConfig.customBackendUrl</td>
			<td>string</td>
			<td>Override Backend URL</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.nginxConfig.customReadUrl</td>
			<td>string</td>
			<td>Override Read URL</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.nginxConfig.customWriteUrl</td>
			<td>string</td>
			<td>Override Write URL</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.nginxConfig.file</td>
			<td>string</td>
			<td>Config file contents for Nginx. Passed through the `tpl` function to allow templating</td>
			<td><pre lang="">
See values.yaml
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.nginxConfig.httpSnippet</td>
			<td>string</td>
			<td>Allows appending custom configuration to the http block, passed through the `tpl` function to allow templating</td>
			<td><pre lang="json">
"{{ if .Values.loki.tenants }}proxy_set_header X-Scope-OrgID $remote_user;{{ end }}"
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.nginxConfig.logFormat</td>
			<td>string</td>
			<td>NGINX log format</td>
			<td><pre lang="json">
"main '$remote_addr - $remote_user [$time_local]  $status '\n        '\"$request\" $body_bytes_sent \"$http_referer\" '\n        '\"$http_user_agent\" \"$http_x_forwarded_for\"';"
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.nginxConfig.serverSnippet</td>
			<td>string</td>
			<td>Allows appending custom configuration to the server block</td>
			<td><pre lang="json">
""
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.nodeSelector</td>
			<td>object</td>
			<td>Node selector for gateway pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.podAnnotations</td>
			<td>object</td>
			<td>Annotations for gateway pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.podLabels</td>
			<td>object</td>
			<td>Additional labels for gateway pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.podSecurityContext</td>
			<td>object</td>
			<td>The SecurityContext for gateway containers</td>
			<td><pre lang="json">
{
  "fsGroup": 101,
  "runAsGroup": 101,
  "runAsNonRoot": true,
  "runAsUser": 101
}
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.priorityClassName</td>
			<td>string</td>
			<td>The name of the PriorityClass for gateway pods</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.readinessProbe.httpGet.path</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/"
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.readinessProbe.httpGet.port</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"http"
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.readinessProbe.initialDelaySeconds</td>
			<td>int</td>
			<td></td>
			<td><pre lang="json">
15
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.readinessProbe.timeoutSeconds</td>
			<td>int</td>
			<td></td>
			<td><pre lang="json">
1
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.replicas</td>
			<td>int</td>
			<td>Number of replicas for the gateway</td>
			<td><pre lang="json">
1
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.resources</td>
			<td>object</td>
			<td>Resource requests and limits for the gateway</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.service.annotations</td>
			<td>object</td>
			<td>Annotations for the gateway service</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.service.clusterIP</td>
			<td>string</td>
			<td>ClusterIP of the gateway service</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.service.labels</td>
			<td>object</td>
			<td>Labels for gateway service</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.service.loadBalancerIP</td>
			<td>string</td>
			<td>Load balancer IPO address if service type is LoadBalancer</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.service.nodePort</td>
			<td>int</td>
			<td>Node port if service type is NodePort</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.service.port</td>
			<td>int</td>
			<td>Port of the gateway service</td>
			<td><pre lang="json">
80
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.service.type</td>
			<td>string</td>
			<td>Type of the gateway service</td>
			<td><pre lang="json">
"ClusterIP"
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.terminationGracePeriodSeconds</td>
			<td>int</td>
			<td>Grace period to allow the gateway to shutdown before it is killed</td>
			<td><pre lang="json">
30
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.tolerations</td>
			<td>list</td>
			<td>Tolerations for gateway pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.verboseLogging</td>
			<td>bool</td>
			<td>Enable logging of 2xx and 3xx HTTP requests</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>global.clusterDomain</td>
			<td>string</td>
			<td>configures cluster domain ("cluster.local" by default)</td>
			<td><pre lang="json">
"cluster.local"
</pre>
</td>
		</tr>
		<tr>
			<td>global.dnsNamespace</td>
			<td>string</td>
			<td>configures DNS service namespace</td>
			<td><pre lang="json">
"kube-system"
</pre>
</td>
		</tr>
		<tr>
			<td>global.dnsService</td>
			<td>string</td>
			<td>configures DNS service name</td>
			<td><pre lang="json">
"kube-dns"
</pre>
</td>
		</tr>
		<tr>
			<td>global.image.registry</td>
			<td>string</td>
			<td>Overrides the Docker registry globally for all images</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>global.priorityClassName</td>
			<td>string</td>
			<td>Overrides the priorityClassName for all pods</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>imagePullSecrets</td>
			<td>list</td>
			<td>Image pull secrets for Docker images</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.annotations</td>
			<td>object</td>
			<td></td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.enabled</td>
			<td>bool</td>
			<td></td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.hosts[0]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"loki.example.com"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.ingressClassName</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
""
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.labels</td>
			<td>object</td>
			<td></td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.read[0]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/api/prom/tail"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.read[1]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/loki/api/v1/tail"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.read[2]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/loki/api"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.read[3]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/api/prom/rules"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.read[4]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/loki/api/v1/rules"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.read[5]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/prometheus/api/v1/rules"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.read[6]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/prometheus/api/v1/alerts"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.singleBinary[0]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/api/prom/push"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.singleBinary[1]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/loki/api/v1/push"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.singleBinary[2]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/api/prom/tail"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.singleBinary[3]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/loki/api/v1/tail"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.singleBinary[4]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/loki/api"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.singleBinary[5]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/api/prom/rules"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.singleBinary[6]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/loki/api/v1/rules"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.singleBinary[7]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/prometheus/api/v1/rules"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.singleBinary[8]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/prometheus/api/v1/alerts"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.write[0]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/api/prom/push"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.write[1]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/loki/api/v1/push"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.tls</td>
			<td>list</td>
			<td></td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>kubectlImage.digest</td>
			<td>string</td>
			<td>Overrides the image tag with an image digest</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>kubectlImage.pullPolicy</td>
			<td>string</td>
			<td>Docker image pull policy</td>
			<td><pre lang="json">
"IfNotPresent"
</pre>
</td>
		</tr>
		<tr>
			<td>kubectlImage.registry</td>
			<td>string</td>
			<td>The Docker registry</td>
			<td><pre lang="json">
"docker.io"
</pre>
</td>
		</tr>
		<tr>
			<td>kubectlImage.repository</td>
			<td>string</td>
			<td>Docker image repository</td>
			<td><pre lang="json">
"bitnami/kubectl"
</pre>
</td>
		</tr>
		<tr>
			<td>kubectlImage.tag</td>
			<td>string</td>
			<td>Overrides the image tag whose default is the chart's appVersion</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>loki.analytics</td>
			<td>object</td>
			<td>Optional analytics configuration</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.annotations</td>
			<td>object</td>
			<td>Common annotations for all deployments/StatefulSets</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.auth_enabled</td>
			<td>bool</td>
			<td></td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>loki.commonConfig</td>
			<td>object</td>
			<td>Check https://grafana.com/docs/loki/latest/configuration/#common_config for more info on how to provide a common configuration</td>
			<td><pre lang="json">
{
  "compactor_address": "{{ include \"loki.compactorAddress\" . }}",
  "path_prefix": "/var/loki",
  "replication_factor": 3
}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.compactor</td>
			<td>object</td>
			<td>Optional compactor configuration</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.config</td>
			<td>string</td>
			<td>Config file contents for Loki</td>
			<td><pre lang="">
See values.yaml
</pre>
</td>
		</tr>
		<tr>
			<td>loki.configStorageType</td>
			<td>string</td>
			<td>Defines what kind of object stores the configuration, a ConfigMap or a Secret. In order to move sensitive information (such as credentials) from the ConfigMap/Secret to a more secure location (e.g. vault), it is possible to use [environment variables in the configuration](https://grafana.com/docs/loki/latest/configuration/#use-environment-variables-in-the-configuration). Such environment variables can be then stored in a separate Secret and injected via the global.extraEnvFrom value. For details about environment injection from a Secret please see [Secrets](https://kubernetes.io/docs/concepts/configuration/secret/#use-case-as-container-environment-variables).</td>
			<td><pre lang="json">
"ConfigMap"
</pre>
</td>
		</tr>
		<tr>
			<td>loki.containerSecurityContext</td>
			<td>object</td>
			<td>The SecurityContext for Loki containers</td>
			<td><pre lang="json">
{
  "allowPrivilegeEscalation": false,
  "capabilities": {
    "drop": [
      "ALL"
    ]
  },
  "readOnlyRootFilesystem": true
}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.enableServiceLinks</td>
			<td>bool</td>
			<td>Should enableServiceLinks be enabled. Default to enable</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>loki.existingSecretForConfig</td>
			<td>string</td>
			<td>Specify an existing secret containing loki configuration. If non-empty, overrides `loki.config`</td>
			<td><pre lang="json">
""
</pre>
</td>
		</tr>
		<tr>
			<td>loki.externalConfigSecretName</td>
			<td>string</td>
			<td>Name of the Secret or ConfigMap that contains the configuration (used for naming even if config is internal).</td>
			<td><pre lang="json">
"{{ include \"loki.name\" . }}"
</pre>
</td>
		</tr>
		<tr>
			<td>loki.extraMemberlistConfig</td>
			<td>object</td>
			<td>Extra memberlist configuration</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.frontend.scheduler_address</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"{{ include \"loki.querySchedulerAddress\" . }}"
</pre>
</td>
		</tr>
		<tr>
			<td>loki.frontend_worker.scheduler_address</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"{{ include \"loki.querySchedulerAddress\" . }}"
</pre>
</td>
		</tr>
		<tr>
			<td>loki.image.digest</td>
			<td>string</td>
			<td>Overrides the image tag with an image digest</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>loki.image.pullPolicy</td>
			<td>string</td>
			<td>Docker image pull policy</td>
			<td><pre lang="json">
"IfNotPresent"
</pre>
</td>
		</tr>
		<tr>
			<td>loki.image.registry</td>
			<td>string</td>
			<td>The Docker registry</td>
			<td><pre lang="json">
"docker.io"
</pre>
</td>
		</tr>
		<tr>
			<td>loki.image.repository</td>
			<td>string</td>
			<td>Docker image repository</td>
			<td><pre lang="json">
"grafana/loki"
</pre>
</td>
		</tr>
		<tr>
			<td>loki.image.tag</td>
			<td>string</td>
			<td>Overrides the image tag whose default is the chart's appVersion TODO: needed for 3rd target backend functionality revert to null or latest once this behavior is relased</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>loki.index_gateway</td>
			<td>object</td>
			<td>Optional index gateway configuration</td>
			<td><pre lang="json">
{
  "mode": "ring"
}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.ingester</td>
			<td>object</td>
			<td>Optional ingester configuration</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.limits_config</td>
			<td>object</td>
			<td>Limits config</td>
			<td><pre lang="json">
{
  "enforce_metric_name": false,
  "max_cache_freshness_per_query": "10m",
  "reject_old_samples": true,
  "reject_old_samples_max_age": "168h",
  "split_queries_by_interval": "15m"
}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.memberlistConfig</td>
			<td>object</td>
			<td>memberlist configuration (overrides embedded default)</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.memcached</td>
			<td>object</td>
			<td>Configure memcached as an external cache for chunk and results cache. Disabled by default must enable and specify a host for each cache you would like to use.</td>
			<td><pre lang="json">
{
  "chunk_cache": {
    "batch_size": 256,
    "enabled": false,
    "host": "",
    "parallelism": 10,
    "service": "memcached-client"
  },
  "results_cache": {
    "default_validity": "12h",
    "enabled": false,
    "host": "",
    "service": "memcached-client",
    "timeout": "500ms"
  }
}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.podAnnotations</td>
			<td>object</td>
			<td>Common annotations for all pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.podLabels</td>
			<td>object</td>
			<td>Common labels for all pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.podSecurityContext</td>
			<td>object</td>
			<td>The SecurityContext for Loki pods</td>
			<td><pre lang="json">
{
  "fsGroup": 10001,
  "runAsGroup": 10001,
  "runAsNonRoot": true,
  "runAsUser": 10001
}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.querier</td>
			<td>object</td>
			<td>Optional querier configuration</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.query_scheduler</td>
			<td>object</td>
			<td>Additional query scheduler config</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.readinessProbe.httpGet.path</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/ready"
</pre>
</td>
		</tr>
		<tr>
			<td>loki.readinessProbe.httpGet.port</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"http-metrics"
</pre>
</td>
		</tr>
		<tr>
			<td>loki.readinessProbe.initialDelaySeconds</td>
			<td>int</td>
			<td></td>
			<td><pre lang="json">
30
</pre>
</td>
		</tr>
		<tr>
			<td>loki.readinessProbe.timeoutSeconds</td>
			<td>int</td>
			<td></td>
			<td><pre lang="json">
1
</pre>
</td>
		</tr>
		<tr>
			<td>loki.revisionHistoryLimit</td>
			<td>int</td>
			<td>The number of old ReplicaSets to retain to allow rollback</td>
			<td><pre lang="json">
10
</pre>
</td>
		</tr>
		<tr>
			<td>loki.rulerConfig</td>
			<td>object</td>
			<td>Check https://grafana.com/docs/loki/latest/configuration/#ruler for more info on configuring ruler</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.runtimeConfig</td>
			<td>object</td>
			<td>Provides a reloadable runtime configuration file for some specific configuration</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.schemaConfig</td>
			<td>object</td>
			<td>Check https://grafana.com/docs/loki/latest/configuration/#schema_config for more info on how to configure schemas</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.server</td>
			<td>object</td>
			<td>Check https://grafana.com/docs/loki/latest/configuration/#server for more info on the server configuration.</td>
			<td><pre lang="json">
{
  "grpc_listen_port": 9095,
  "http_listen_port": 3100
}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.storage</td>
			<td>object</td>
			<td>Storage config. Providing this will automatically populate all necessary storage configs in the templated config.</td>
			<td><pre lang="json">
{
  "azure": {
    "accountKey": null,
    "accountName": null,
    "endpointSuffix": null,
    "requestTimeout": null,
    "useFederatedToken": false,
    "useManagedIdentity": false,
    "userAssignedId": null
  },
  "bucketNames": {
    "admin": "admin",
    "chunks": "chunks",
    "ruler": "ruler"
  },
  "filesystem": {
    "chunks_directory": "/var/loki/chunks",
    "rules_directory": "/var/loki/rules"
  },
  "gcs": {
    "chunkBufferSize": 0,
    "enableHttp2": true,
    "requestTimeout": "0s"
  },
  "s3": {
    "accessKeyId": null,
    "endpoint": null,
    "http_config": {},
    "insecure": false,
    "region": null,
    "s3": null,
    "s3ForcePathStyle": false,
    "secretAccessKey": null,
    "signatureVersion": null
  },
  "type": "s3"
}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.storage_config</td>
			<td>object</td>
			<td>Additional storage config</td>
			<td><pre lang="json">
{
  "hedging": {
    "at": "250ms",
    "max_per_second": 20,
    "up_to": 3
  }
}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.structuredConfig</td>
			<td>object</td>
			<td>Structured loki configuration, takes precedence over `loki.config`, `loki.schemaConfig`, `loki.storageConfig`</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.tenants</td>
			<td>list</td>
			<td>Tenants list to be created on nginx htpasswd file, with name and password keys</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>memberlist.service.publishNotReadyAddresses</td>
			<td>bool</td>
			<td></td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>migrate</td>
			<td>object</td>
			<td>Options that may be necessary when performing a migration from another helm chart</td>
			<td><pre lang="json">
{
  "fromDistributed": {
    "enabled": false,
    "memberlistService": ""
  }
}
</pre>
</td>
		</tr>
		<tr>
			<td>migrate.fromDistributed</td>
			<td>object</td>
			<td>When migrating from a distributed chart like loki-distributed or enterprise-logs</td>
			<td><pre lang="json">
{
  "enabled": false,
  "memberlistService": ""
}
</pre>
</td>
		</tr>
		<tr>
			<td>migrate.fromDistributed.enabled</td>
			<td>bool</td>
			<td>Set to true if migrating from a distributed helm chart</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>migrate.fromDistributed.memberlistService</td>
			<td>string</td>
			<td>If migrating from a distributed service, provide the distributed deployment's memberlist service DNS so the new deployment can join its ring.</td>
			<td><pre lang="json">
""
</pre>
</td>
		</tr>
		<tr>
			<td>minio</td>
			<td>object</td>
			<td>-----------------------------------</td>
			<td><pre lang="json">
{
  "buckets": [
    {
      "name": "chunks",
      "policy": "none",
      "purge": false
    },
    {
      "name": "ruler",
      "policy": "none",
      "purge": false
    },
    {
      "name": "admin",
      "policy": "none",
      "purge": false
    }
  ],
  "drivesPerNode": 2,
  "enabled": false,
  "persistence": {
    "size": "5Gi"
  },
  "replicas": 1,
  "resources": {
    "requests": {
      "cpu": "100m",
      "memory": "128Mi"
    }
  },
  "rootPassword": "supersecret",
  "rootUser": "enterprise-logs"
}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.dashboards.annotations</td>
			<td>object</td>
			<td>Additional annotations for the dashboards ConfigMap</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.dashboards.enabled</td>
			<td>bool</td>
			<td>If enabled, create configmap with dashboards for monitoring Loki</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.dashboards.labels</td>
			<td>object</td>
			<td>Labels for the dashboards ConfigMap</td>
			<td><pre lang="json">
{
  "grafana_dashboard": "1"
}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.dashboards.namespace</td>
			<td>string</td>
			<td>Alternative namespace to create dashboards ConfigMap in</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.lokiCanary.annotations</td>
			<td>object</td>
			<td>Additional annotations for the `loki-canary` Daemonset</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.lokiCanary.enabled</td>
			<td>bool</td>
			<td></td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.lokiCanary.extraArgs</td>
			<td>list</td>
			<td>Additional CLI arguments for the `loki-canary' command</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.lokiCanary.extraEnv</td>
			<td>list</td>
			<td>Environment variables to add to the canary pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.lokiCanary.extraEnvFrom</td>
			<td>list</td>
			<td>Environment variables from secrets or configmaps to add to the canary pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.lokiCanary.image</td>
			<td>object</td>
			<td>Image to use for loki canary</td>
			<td><pre lang="json">
{
  "digest": null,
  "pullPolicy": "IfNotPresent",
  "registry": "docker.io",
  "repository": "grafana/loki-canary",
  "tag": null
}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.lokiCanary.image.digest</td>
			<td>string</td>
			<td>Overrides the image tag with an image digest</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.lokiCanary.image.pullPolicy</td>
			<td>string</td>
			<td>Docker image pull policy</td>
			<td><pre lang="json">
"IfNotPresent"
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.lokiCanary.image.registry</td>
			<td>string</td>
			<td>The Docker registry</td>
			<td><pre lang="json">
"docker.io"
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.lokiCanary.image.repository</td>
			<td>string</td>
			<td>Docker image repository</td>
			<td><pre lang="json">
"grafana/loki-canary"
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.lokiCanary.image.tag</td>
			<td>string</td>
			<td>Overrides the image tag whose default is the chart's appVersion</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.lokiCanary.labelname</td>
			<td>string</td>
			<td>The name of the label to look for at loki when doing the checks.</td>
			<td><pre lang="json">
"pod"
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.lokiCanary.nodeSelector</td>
			<td>object</td>
			<td>Node selector for canary pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.lokiCanary.podLabels</td>
			<td>object</td>
			<td>Additional labels for each `loki-canary` pod</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.lokiCanary.priorityClassName</td>
			<td>string</td>
			<td>The name of the PriorityClass for loki-canary pods</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.lokiCanary.resources</td>
			<td>object</td>
			<td>Resource requests and limits for the canary</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.lokiCanary.tolerations</td>
			<td>list</td>
			<td>Tolerations for canary pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.lokiCanary.updateStrategy</td>
			<td>object</td>
			<td>Update strategy for the `loki-canary` Daemonset pods</td>
			<td><pre lang="json">
{
  "rollingUpdate": {
    "maxUnavailable": 1
  },
  "type": "RollingUpdate"
}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.rules.additionalGroups</td>
			<td>list</td>
			<td>Additional groups to add to the rules file</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.rules.additionalRuleLabels</td>
			<td>object</td>
			<td>Additional labels for PrometheusRule alerts</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.rules.alerting</td>
			<td>bool</td>
			<td>Include alerting rules</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.rules.annotations</td>
			<td>object</td>
			<td>Additional annotations for the rules PrometheusRule resource</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.rules.enabled</td>
			<td>bool</td>
			<td>If enabled, create PrometheusRule resource with Loki recording rules</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.rules.labels</td>
			<td>object</td>
			<td>Additional labels for the rules PrometheusRule resource</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.rules.namespace</td>
			<td>string</td>
			<td>Alternative namespace to create PrometheusRule resources in</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.enabled</td>
			<td>bool</td>
			<td></td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.grafanaAgent.annotations</td>
			<td>object</td>
			<td>Grafana Agent annotations</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.grafanaAgent.enableConfigReadAPI</td>
			<td>bool</td>
			<td>Enable the config read api on port 8080 of the agent</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.grafanaAgent.installOperator</td>
			<td>bool</td>
			<td>Controls whether to install the Grafana Agent Operator and its CRDs. Note that helm will not install CRDs if this flag is enabled during an upgrade. In that case install the CRDs manually from https://github.com/grafana/agent/tree/main/production/operator/crds</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.grafanaAgent.labels</td>
			<td>object</td>
			<td>Additional Grafana Agent labels</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.grafanaAgent.priorityClassName</td>
			<td>string</td>
			<td>The name of the PriorityClass for GrafanaAgent pods</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.logsInstance.annotations</td>
			<td>object</td>
			<td>LogsInstance annotations</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.logsInstance.clients</td>
			<td>string</td>
			<td>Additional clients for remote write</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.logsInstance.labels</td>
			<td>object</td>
			<td>Additional LogsInstance labels</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.podLogs.annotations</td>
			<td>object</td>
			<td>PodLogs annotations</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.podLogs.labels</td>
			<td>object</td>
			<td>Additional PodLogs labels</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.podLogs.relabelings</td>
			<td>list</td>
			<td>PodLogs relabel configs to apply to samples before scraping https://github.com/prometheus-operator/prometheus-operator/blob/master/Documentation/api.md#relabelconfig</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.tenant</td>
			<td>object</td>
			<td>Tenant to use for self monitoring</td>
			<td><pre lang="json">
{
  "name": "self-monitoring",
  "secretNamespace": "{{ .Release.Namespace }}"
}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.tenant.name</td>
			<td>string</td>
			<td>Name of the tenant</td>
			<td><pre lang="json">
"self-monitoring"
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.tenant.secretNamespace</td>
			<td>string</td>
			<td>Namespace to create additional tenant token secret in. Useful if your Grafana instance is in a separate namespace. Token will still be created in the canary namespace.</td>
			<td><pre lang="json">
"{{ .Release.Namespace }}"
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.annotations</td>
			<td>object</td>
			<td>ServiceMonitor annotations</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.enabled</td>
			<td>bool</td>
			<td>If enabled, ServiceMonitor resources for Prometheus Operator are created</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.interval</td>
			<td>string</td>
			<td>ServiceMonitor scrape interval Default is 15s because included recording rules use a 1m rate, and scrape interval needs to be at least 1/4 rate interval.</td>
			<td><pre lang="json">
"15s"
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.labels</td>
			<td>object</td>
			<td>Additional ServiceMonitor labels</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.metricRelabelings</td>
			<td>list</td>
			<td>ServiceMonitor metric relabel configs to apply to samples before ingestion https://github.com/prometheus-operator/prometheus-operator/blob/main/Documentation/api.md#endpoint</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.metricsInstance</td>
			<td>object</td>
			<td>If defined, will create a MetricsInstance for the Grafana Agent Operator.</td>
			<td><pre lang="json">
{
  "annotations": {},
  "enabled": true,
  "labels": {},
  "remoteWrite": null
}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.metricsInstance.annotations</td>
			<td>object</td>
			<td>MetricsInstance annotations</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.metricsInstance.enabled</td>
			<td>bool</td>
			<td>If enabled, MetricsInstance resources for Grafana Agent Operator are created</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.metricsInstance.labels</td>
			<td>object</td>
			<td>Additional MetricsInstance labels</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.metricsInstance.remoteWrite</td>
			<td>string</td>
			<td>If defined a MetricsInstance will be created to remote write metrics.</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.namespaceSelector</td>
			<td>object</td>
			<td>Namespace selector for ServiceMonitor resources</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.relabelings</td>
			<td>list</td>
			<td>ServiceMonitor relabel configs to apply to samples before scraping https://github.com/prometheus-operator/prometheus-operator/blob/master/Documentation/api.md#relabelconfig</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.scheme</td>
			<td>string</td>
			<td>ServiceMonitor will use http by default, but you can pick https as well</td>
			<td><pre lang="json">
"http"
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.scrapeTimeout</td>
			<td>string</td>
			<td>ServiceMonitor scrape timeout in Go duration format (e.g. 15s)</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.tlsConfig</td>
			<td>string</td>
			<td>ServiceMonitor will use these tlsConfig settings to make the health check requests</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>nameOverride</td>
			<td>string</td>
			<td>Overrides the chart's name</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.alertmanager.namespaceSelector</td>
			<td>object</td>
			<td>Specifies the namespace the alertmanager is running in</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.alertmanager.podSelector</td>
			<td>object</td>
			<td>Specifies the alertmanager Pods. As this is cross-namespace communication, you also need the namespaceSelector.</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.alertmanager.port</td>
			<td>int</td>
			<td>Specify the alertmanager port used for alerting</td>
			<td><pre lang="json">
9093
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.discovery.namespaceSelector</td>
			<td>object</td>
			<td>Specifies the namespace the discovery Pods are running in</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.discovery.podSelector</td>
			<td>object</td>
			<td>Specifies the Pods labels used for discovery. As this is cross-namespace communication, you also need the namespaceSelector.</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.discovery.port</td>
			<td>int</td>
			<td>Specify the port used for discovery</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.enabled</td>
			<td>bool</td>
			<td>Specifies whether Network Policies should be created</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.externalStorage.cidrs</td>
			<td>list</td>
			<td>Specifies specific network CIDRs you want to limit access to</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.externalStorage.ports</td>
			<td>list</td>
			<td>Specify the port used for external storage, e.g. AWS S3</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.ingress.namespaceSelector</td>
			<td>object</td>
			<td>Specifies the namespaces which are allowed to access the http port</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.ingress.podSelector</td>
			<td>object</td>
			<td>Specifies the Pods which are allowed to access the http port. As this is cross-namespace communication, you also need the namespaceSelector.</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.metrics.cidrs</td>
			<td>list</td>
			<td>Specifies specific network CIDRs which are allowed to access the metrics port. In case you use namespaceSelector, you also have to specify your kubelet networks here. The metrics ports are also used for probes.</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.metrics.namespaceSelector</td>
			<td>object</td>
			<td>Specifies the namespaces which are allowed to access the metrics port</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.metrics.podSelector</td>
			<td>object</td>
			<td>Specifies the Pods which are allowed to access the metrics port. As this is cross-namespace communication, you also need the namespaceSelector.</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>rbac.pspEnabled</td>
			<td>bool</td>
			<td>If pspEnabled true, a PodSecurityPolicy is created for K8s that use psp.</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>rbac.sccEnabled</td>
			<td>bool</td>
			<td>For OpenShift set pspEnabled to 'false' and sccEnabled to 'true' to use the SecurityContextConstraints.</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>read.affinity</td>
			<td>string</td>
			<td>Affinity for read pods. Passed through `tpl` and, thus, to be configured as string</td>
			<td><pre lang="">
Hard node and soft zone anti-affinity
</pre>
</td>
		</tr>
		<tr>
			<td>read.annotations</td>
			<td>object</td>
			<td>Annotations for read deployment</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>read.autoscaling.behavior</td>
			<td>object</td>
			<td>Behavior policies while scaling.</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>read.autoscaling.enabled</td>
			<td>bool</td>
			<td>Enable autoscaling for the read, this is only used if `queryIndex.enabled: true`</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>read.autoscaling.maxReplicas</td>
			<td>int</td>
			<td>Maximum autoscaling replicas for the read</td>
			<td><pre lang="json">
3
</pre>
</td>
		</tr>
		<tr>
			<td>read.autoscaling.minReplicas</td>
			<td>int</td>
			<td>Minimum autoscaling replicas for the read</td>
			<td><pre lang="json">
1
</pre>
</td>
		</tr>
		<tr>
			<td>read.autoscaling.targetCPUUtilizationPercentage</td>
			<td>int</td>
			<td>Target CPU utilisation percentage for the read</td>
			<td><pre lang="json">
60
</pre>
</td>
		</tr>
		<tr>
			<td>read.autoscaling.targetMemoryUtilizationPercentage</td>
			<td>string</td>
			<td>Target memory utilisation percentage for the read</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>read.extraArgs</td>
			<td>list</td>
			<td>Additional CLI args for the read</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>read.extraEnv</td>
			<td>list</td>
			<td>Environment variables to add to the read pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>read.extraEnvFrom</td>
			<td>list</td>
			<td>Environment variables from secrets or configmaps to add to the read pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>read.extraVolumeMounts</td>
			<td>list</td>
			<td>Volume mounts to add to the read pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>read.extraVolumes</td>
			<td>list</td>
			<td>Volumes to add to the read pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>read.image.registry</td>
			<td>string</td>
			<td>The Docker registry for the read image. Overrides `loki.image.registry`</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>read.image.repository</td>
			<td>string</td>
			<td>Docker image repository for the read image. Overrides `loki.image.repository`</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>read.image.tag</td>
			<td>string</td>
			<td>Docker image tag for the read image. Overrides `loki.image.tag`</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>read.legacyReadTarget</td>
			<td>bool</td>
			<td>Whether or not to use the 2 target type simple scalable mode (read, write) or the 3 target type (read, write, backend). Legacy refers to the 2 target type, so true will run two targets, false will run 3 targets.</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>read.lifecycle</td>
			<td>object</td>
			<td>Lifecycle for the read container</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>read.nodeSelector</td>
			<td>object</td>
			<td>Node selector for read pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>read.persistence.enableStatefulSetAutoDeletePVC</td>
			<td>bool</td>
			<td>Enable StatefulSetAutoDeletePVC feature</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>read.persistence.selector</td>
			<td>string</td>
			<td>Selector for persistent disk</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>read.persistence.size</td>
			<td>string</td>
			<td>Size of persistent disk</td>
			<td><pre lang="json">
"10Gi"
</pre>
</td>
		</tr>
		<tr>
			<td>read.persistence.storageClass</td>
			<td>string</td>
			<td>Storage class to be used. If defined, storageClassName: <storageClass>. If set to "-", storageClassName: "", which disables dynamic provisioning. If empty or set to null, no storageClassName spec is set, choosing the default provisioner (gp2 on AWS, standard on GKE, AWS, and OpenStack).</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>read.podAnnotations</td>
			<td>object</td>
			<td>Annotations for read pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>read.podLabels</td>
			<td>object</td>
			<td>Additional labels for each `read` pod</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>read.podManagementPolicy</td>
			<td>string</td>
			<td>The default is to deploy all pods in parallel.</td>
			<td><pre lang="json">
"Parallel"
</pre>
</td>
		</tr>
		<tr>
			<td>read.priorityClassName</td>
			<td>string</td>
			<td>The name of the PriorityClass for read pods</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>read.replicas</td>
			<td>int</td>
			<td>Number of replicas for the read</td>
			<td><pre lang="json">
3
</pre>
</td>
		</tr>
		<tr>
			<td>read.resources</td>
			<td>object</td>
			<td>Resource requests and limits for the read</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>read.selectorLabels</td>
			<td>object</td>
			<td>Additional selector labels for each `read` pod</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>read.serviceLabels</td>
			<td>object</td>
			<td>Labels for read service</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>read.targetModule</td>
			<td>string</td>
			<td>Comma-separated list of Loki modules to load for the read</td>
			<td><pre lang="json">
"read"
</pre>
</td>
		</tr>
		<tr>
			<td>read.terminationGracePeriodSeconds</td>
			<td>int</td>
			<td>Grace period to allow the read to shutdown before it is killed</td>
			<td><pre lang="json">
30
</pre>
</td>
		</tr>
		<tr>
			<td>read.tolerations</td>
			<td>list</td>
			<td>Tolerations for read pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>serviceAccount.annotations</td>
			<td>object</td>
			<td>Annotations for the service account</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>serviceAccount.automountServiceAccountToken</td>
			<td>bool</td>
			<td>Set this toggle to false to opt out of automounting API credentials for the service account</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>serviceAccount.create</td>
			<td>bool</td>
			<td>Specifies whether a ServiceAccount should be created</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>serviceAccount.imagePullSecrets</td>
			<td>list</td>
			<td>Image pull secrets for the service account</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>serviceAccount.labels</td>
			<td>object</td>
			<td>Labels for the service account</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>serviceAccount.name</td>
			<td>string</td>
			<td>The name of the ServiceAccount to use. If not set and create is true, a name is generated using the fullname template</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.affinity</td>
			<td>string</td>
			<td>Affinity for single binary pods. Passed through `tpl` and, thus, to be configured as string</td>
			<td><pre lang="">
Hard node and soft zone anti-affinity
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.annotations</td>
			<td>object</td>
			<td>Annotations for single binary StatefulSet</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.autoscaling.enabled</td>
			<td>bool</td>
			<td>Enable autoscaling</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.autoscaling.maxReplicas</td>
			<td>int</td>
			<td>Maximum autoscaling replicas for the single binary</td>
			<td><pre lang="json">
3
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.autoscaling.minReplicas</td>
			<td>int</td>
			<td>Minimum autoscaling replicas for the single binary</td>
			<td><pre lang="json">
1
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.autoscaling.targetCPUUtilizationPercentage</td>
			<td>int</td>
			<td>Target CPU utilisation percentage for the single binary</td>
			<td><pre lang="json">
60
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.autoscaling.targetMemoryUtilizationPercentage</td>
			<td>string</td>
			<td>Target memory utilisation percentage for the single binary</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.extraArgs</td>
			<td>list</td>
			<td>Labels for single binary service</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.extraContainers</td>
			<td>list</td>
			<td>Extra containers to add to the single binary loki pod</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.extraEnv</td>
			<td>list</td>
			<td>Environment variables to add to the single binary pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.extraEnvFrom</td>
			<td>list</td>
			<td>Environment variables from secrets or configmaps to add to the single binary pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.extraVolumeMounts</td>
			<td>list</td>
			<td>Volume mounts to add to the single binary pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.extraVolumes</td>
			<td>list</td>
			<td>Volumes to add to the single binary pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.image.registry</td>
			<td>string</td>
			<td>The Docker registry for the single binary image. Overrides `loki.image.registry`</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.image.repository</td>
			<td>string</td>
			<td>Docker image repository for the single binary image. Overrides `loki.image.repository`</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.image.tag</td>
			<td>string</td>
			<td>Docker image tag for the single binary image. Overrides `loki.image.tag`</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.initContainers</td>
			<td>list</td>
			<td>Init containers to add to the single binary pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.nodeSelector</td>
			<td>object</td>
			<td>Node selector for single binary pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.persistence.enableStatefulSetAutoDeletePVC</td>
			<td>bool</td>
			<td>Enable StatefulSetAutoDeletePVC feature</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.persistence.enabled</td>
			<td>bool</td>
			<td>Enable persistent disk</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.persistence.selector</td>
			<td>string</td>
			<td>Selector for persistent disk</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.persistence.size</td>
			<td>string</td>
			<td>Size of persistent disk</td>
			<td><pre lang="json">
"10Gi"
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.persistence.storageClass</td>
			<td>string</td>
			<td>Storage class to be used. If defined, storageClassName: <storageClass>. If set to "-", storageClassName: "", which disables dynamic provisioning. If empty or set to null, no storageClassName spec is set, choosing the default provisioner (gp2 on AWS, standard on GKE, AWS, and OpenStack).</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.podAnnotations</td>
			<td>object</td>
			<td>Annotations for single binary pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.podLabels</td>
			<td>object</td>
			<td>Additional labels for each `single binary` pod</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.priorityClassName</td>
			<td>string</td>
			<td>The name of the PriorityClass for single binary pods</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.replicas</td>
			<td>int</td>
			<td>Number of replicas for the single binary</td>
			<td><pre lang="json">
0
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.resources</td>
			<td>object</td>
			<td>Resource requests and limits for the single binary</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.selectorLabels</td>
			<td>object</td>
			<td>Additional selector labels for each `single binary` pod</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.targetModule</td>
			<td>string</td>
			<td>Comma-separated list of Loki modules to load for the single binary</td>
			<td><pre lang="json">
"all"
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.terminationGracePeriodSeconds</td>
			<td>int</td>
			<td>Grace period to allow the single binary to shutdown before it is killed</td>
			<td><pre lang="json">
30
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.tolerations</td>
			<td>list</td>
			<td>Tolerations for single binary pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>tableManager.affinity</td>
			<td>string</td>
			<td>Affinity for table-manager pods. Passed through `tpl` and, thus, to be configured as string</td>
			<td><pre lang="">
Hard node and soft zone anti-affinity
</pre>
</td>
		</tr>
		<tr>
			<td>tableManager.annotations</td>
			<td>object</td>
			<td>Annotations for table-manager deployment</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>tableManager.command</td>
			<td>string</td>
			<td>Command to execute instead of defined in Docker image</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>tableManager.enabled</td>
			<td>bool</td>
			<td>Specifies whether the table-manager should be enabled</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>tableManager.extraArgs</td>
			<td>list</td>
			<td>Additional CLI args for the table-manager</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>tableManager.extraContainers</td>
			<td>list</td>
			<td>Containers to add to the table-manager pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>tableManager.extraEnv</td>
			<td>list</td>
			<td>Environment variables to add to the table-manager pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>tableManager.extraEnvFrom</td>
			<td>list</td>
			<td>Environment variables from secrets or configmaps to add to the table-manager pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>tableManager.extraVolumeMounts</td>
			<td>list</td>
			<td>Volume mounts to add to the table-manager pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>tableManager.extraVolumes</td>
			<td>list</td>
			<td>Volumes to add to the table-manager pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>tableManager.image.registry</td>
			<td>string</td>
			<td>The Docker registry for the table-manager image. Overrides `loki.image.registry`</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>tableManager.image.repository</td>
			<td>string</td>
			<td>Docker image repository for the table-manager image. Overrides `loki.image.repository`</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>tableManager.image.tag</td>
			<td>string</td>
			<td>Docker image tag for the table-manager image. Overrides `loki.image.tag`</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>tableManager.nodeSelector</td>
			<td>object</td>
			<td>Node selector for table-manager pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>tableManager.podAnnotations</td>
			<td>object</td>
			<td>Annotations for table-manager pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>tableManager.podLabels</td>
			<td>object</td>
			<td>Labels for table-manager pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>tableManager.priorityClassName</td>
			<td>string</td>
			<td>The name of the PriorityClass for table-manager pods</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>tableManager.resources</td>
			<td>object</td>
			<td>Resource requests and limits for the table-manager</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>tableManager.retention_deletes_enabled</td>
			<td>bool</td>
			<td>Enable deletes by retention</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>tableManager.retention_period</td>
			<td>int</td>
			<td>Set retention period</td>
			<td><pre lang="json">
0
</pre>
</td>
		</tr>
		<tr>
			<td>tableManager.serviceLabels</td>
			<td>object</td>
			<td>Labels for table-manager service</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>tableManager.terminationGracePeriodSeconds</td>
			<td>int</td>
			<td>Grace period to allow the table-manager to shutdown before it is killed</td>
			<td><pre lang="json">
30
</pre>
</td>
		</tr>
		<tr>
			<td>tableManager.tolerations</td>
			<td>list</td>
			<td>Tolerations for table-manager pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>test</td>
			<td>object</td>
			<td>Section for configuring optional Helm test</td>
			<td><pre lang="json">
{
  "annotations": {},
  "enabled": true,
  "image": {
    "digest": null,
    "pullPolicy": "IfNotPresent",
    "registry": "docker.io",
    "repository": "grafana/loki-helm-test",
    "tag": null
  },
  "labels": {},
  "prometheusAddress": "http://prometheus:9090",
  "timeout": "1m"
}
</pre>
</td>
		</tr>
		<tr>
			<td>test.annotations</td>
			<td>object</td>
			<td>Additional annotations for test pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>test.image</td>
			<td>object</td>
			<td>Image to use for loki canary</td>
			<td><pre lang="json">
{
  "digest": null,
  "pullPolicy": "IfNotPresent",
  "registry": "docker.io",
  "repository": "grafana/loki-helm-test",
  "tag": null
}
</pre>
</td>
		</tr>
		<tr>
			<td>test.image.digest</td>
			<td>string</td>
			<td>Overrides the image tag with an image digest</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>test.image.pullPolicy</td>
			<td>string</td>
			<td>Docker image pull policy</td>
			<td><pre lang="json">
"IfNotPresent"
</pre>
</td>
		</tr>
		<tr>
			<td>test.image.registry</td>
			<td>string</td>
			<td>The Docker registry</td>
			<td><pre lang="json">
"docker.io"
</pre>
</td>
		</tr>
		<tr>
			<td>test.image.repository</td>
			<td>string</td>
			<td>Docker image repository</td>
			<td><pre lang="json">
"grafana/loki-helm-test"
</pre>
</td>
		</tr>
		<tr>
			<td>test.image.tag</td>
			<td>string</td>
			<td>Overrides the image tag whose default is the chart's appVersion</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>test.labels</td>
			<td>object</td>
			<td>Additional labels for the test pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>test.prometheusAddress</td>
			<td>string</td>
			<td>Address of the prometheus server to query for the test</td>
			<td><pre lang="json">
"http://prometheus:9090"
</pre>
</td>
		</tr>
		<tr>
			<td>test.timeout</td>
			<td>string</td>
			<td>Number of times to retry the test before failing</td>
			<td><pre lang="json">
"1m"
</pre>
</td>
		</tr>
		<tr>
			<td>tracing.jaegerAgentHost</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
""
</pre>
</td>
		</tr>
		<tr>
			<td>write.affinity</td>
			<td>string</td>
			<td>Affinity for write pods. Passed through `tpl` and, thus, to be configured as string</td>
			<td><pre lang="">
Hard node and soft zone anti-affinity
</pre>
</td>
		</tr>
		<tr>
			<td>write.annotations</td>
			<td>object</td>
			<td>Annotations for write StatefulSet</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>write.autoscaling.behavior</td>
			<td>object</td>
			<td>Behavior policies while scaling.</td>
			<td><pre lang="json">
{
  "scaleDown": {
    "policies": [
      {
        "periodSeconds": 1800,
        "type": "Pods",
        "value": 1
      }
    ],
    "stabilizationWindowSeconds": 3600
  },
  "scaleUp": {
    "policies": [
      {
        "periodSeconds": 900,
        "type": "Pods",
        "value": 1
      }
    ]
  }
}
</pre>
</td>
		</tr>
		<tr>
			<td>write.autoscaling.behavior.scaleUp</td>
			<td>object</td>
			<td>see https://github.com/grafana/loki/blob/main/docs/sources/operations/storage/wal.md#how-to-scale-updown for scaledown details</td>
			<td><pre lang="json">
{
  "policies": [
    {
      "periodSeconds": 900,
      "type": "Pods",
      "value": 1
    }
  ]
}
</pre>
</td>
		</tr>
		<tr>
			<td>write.autoscaling.enabled</td>
			<td>bool</td>
			<td>Enable autoscaling for the write.</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>write.autoscaling.maxReplicas</td>
			<td>int</td>
			<td>Maximum autoscaling replicas for the write.</td>
			<td><pre lang="json">
3
</pre>
</td>
		</tr>
		<tr>
			<td>write.autoscaling.minReplicas</td>
			<td>int</td>
			<td>Minimum autoscaling replicas for the write.</td>
			<td><pre lang="json">
1
</pre>
</td>
		</tr>
		<tr>
			<td>write.autoscaling.targetCPUUtilizationPercentage</td>
			<td>int</td>
			<td>Target CPU utilisation percentage for the write.</td>
			<td><pre lang="json">
60
</pre>
</td>
		</tr>
		<tr>
			<td>write.autoscaling.targetMemoryUtilizationPercentage</td>
			<td>string</td>
			<td>Target memory utilization percentage for the write.</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>write.extraArgs</td>
			<td>list</td>
			<td>Additional CLI args for the write</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>write.extraEnv</td>
			<td>list</td>
			<td>Environment variables to add to the write pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>write.extraEnvFrom</td>
			<td>list</td>
			<td>Environment variables from secrets or configmaps to add to the write pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>write.extraVolumeClaimTemplates</td>
			<td>list</td>
			<td>volumeClaimTemplates to add to StatefulSet</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>write.extraVolumeMounts</td>
			<td>list</td>
			<td>Volume mounts to add to the write pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>write.extraVolumes</td>
			<td>list</td>
			<td>Volumes to add to the write pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>write.image.registry</td>
			<td>string</td>
			<td>The Docker registry for the write image. Overrides `loki.image.registry`</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>write.image.repository</td>
			<td>string</td>
			<td>Docker image repository for the write image. Overrides `loki.image.repository`</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>write.image.tag</td>
			<td>string</td>
			<td>Docker image tag for the write image. Overrides `loki.image.tag`</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>write.initContainers</td>
			<td>list</td>
			<td>Init containers to add to the write pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>write.lifecycle</td>
			<td>object</td>
			<td>Lifecycle for the write container</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>write.nodeSelector</td>
			<td>object</td>
			<td>Node selector for write pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>write.persistence.enableStatefulSetAutoDeletePVC</td>
			<td>bool</td>
			<td>Enable StatefulSetAutoDeletePVC feature</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>write.persistence.selector</td>
			<td>string</td>
			<td>Selector for persistent disk</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>write.persistence.size</td>
			<td>string</td>
			<td>Size of persistent disk</td>
			<td><pre lang="json">
"10Gi"
</pre>
</td>
		</tr>
		<tr>
			<td>write.persistence.storageClass</td>
			<td>string</td>
			<td>Storage class to be used. If defined, storageClassName: <storageClass>. If set to "-", storageClassName: "", which disables dynamic provisioning. If empty or set to null, no storageClassName spec is set, choosing the default provisioner (gp2 on AWS, standard on GKE, AWS, and OpenStack).</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>write.podAnnotations</td>
			<td>object</td>
			<td>Annotations for write pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>write.podLabels</td>
			<td>object</td>
			<td>Additional labels for each `write` pod</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>write.podManagementPolicy</td>
			<td>string</td>
			<td>The default is to deploy all pods in parallel.</td>
			<td><pre lang="json">
"Parallel"
</pre>
</td>
		</tr>
		<tr>
			<td>write.priorityClassName</td>
			<td>string</td>
			<td>The name of the PriorityClass for write pods</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>write.replicas</td>
			<td>int</td>
			<td>Number of replicas for the write</td>
			<td><pre lang="json">
3
</pre>
</td>
		</tr>
		<tr>
			<td>write.resources</td>
			<td>object</td>
			<td>Resource requests and limits for the write</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>write.selectorLabels</td>
			<td>object</td>
			<td>Additional selector labels for each `write` pod</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>write.serviceLabels</td>
			<td>object</td>
			<td>Labels for ingester service</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>write.targetModule</td>
			<td>string</td>
			<td>Comma-separated list of Loki modules to load for the write</td>
			<td><pre lang="json">
"write"
</pre>
</td>
		</tr>
		<tr>
			<td>write.terminationGracePeriodSeconds</td>
			<td>int</td>
			<td>Grace period to allow the write to shutdown before it is killed. Especially for the ingester, this must be increased. It must be long enough so writes can be gracefully shutdown flushing/transferring all data and to successfully leave the member ring on shutdown.</td>
			<td><pre lang="json">
300
</pre>
</td>
		</tr>
		<tr>
			<td>write.tolerations</td>
			<td>list</td>
			<td>Tolerations for write pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
	</tbody>
</table>
{{< /responsive-table >}}

